@@ -21,10 +21,10 @@
 #include "evolutionsettings.h"
 #include "evolutioncalendar.h"
 #include "evolutionaddressbook.h"
-#include "mailimporter/filterevolution_v3.h"
-#include "mailimporter/filterinfo.h"
+#include <MailImporter/FilterEvolution_v3>
+#include <MailImporter/FilterInfo>
 
-#include "MailCommon/FilterImporterExporter"
+#include <MailCommon/FilterImporterExporter>
 #include <KPluginFactory>
 
 #include <KLocalizedString>
